********************************************
**POLITICAL SCANDAL EXPERIMENT - 2009 CCES**
********************************************
cd "SET WORKING DIRECTORY"

/*RECODING AS NECESSARY, DROPPING UNUNSED CASES AND VARIABLES
use "cces09_yale_output.dta", clear

set more 1

* On Form C
keep if yal_form ==3

** Treatment Status
rename yal51_treat scantreat
label var scantreat "Treatment Status (1=control;2=infidelity;3=infidelity/abuse;4=financial;5=financial/abuse)"

tab scantreat, gen(scandal_)
rename scandal_1 noscandal

gen s_type_moral=scandal_2+scandal_3
gen s_type_finan=scandal_4+scandal_5
gen s_abuse_yes=scandal_3+scandal_5
gen s_abuse_no=scandal_2+scandal_4

label var s_type_moral "Infidelity Scandal (1=yes)"
label var s_type_finan "Financial Scandal (1=yes)"
label var s_abuse_yes "Abuse of Power (1=yes)"
label var s_abuse_no "No Abuse of Power (1=yes)"

rename scandal_2 scandal_moral
rename scandal_3 scandal_moral_ab
rename scandal_4 scandal_fin
rename scandal_5 scandal_fin_ab

label var scandal_moral "Infidelity Scandal (No Abuse)"
label var scandal_moral_ab "Infidelity Scandal (Abuse)"
label var scandal_fin "Financial Scandal (No Abuse)"
label var scandal_fin_ab "Financial Scandal (Abuse)"

** Party of Representative
recode yal51_party (1=-1) (2=1) (3=0), gen(scanpty)
label var scanpty "Party of Rep. (-1=Democrat;0=no party stated;1=Republican)"

** Outcome Measures (4)
* Job rating
recode yala51 (998=.), gen(scan_job)
sum scan_job if scantreat==1
replace scan_job=(scan_job-r(mean))/r(sd)
label var scan_job "Job Evaluation (poor-excellent)"
* Feel about...as person
recode yala52 (998=.), gen(scan_pers)
sum scan_pers if scantreat==1
replace scan_pers=(scan_pers-r(mean))/r(sd)
label var scan_pers "Personal Evaluation (negative-positive)"
* Likelihood of voting for
recode yala53 (998=.), gen(scan_vote)
sum scan_vote if scantreat==1
replace scan_vote=(scan_vote-r(mean))/r(sd)
label var scan_vote "Vote Intent (not very likely-very likely)"

** DEMOGRAPHICS
gen race=v211
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

gen age=v288
sum age 
replace age=age-r(mean)
gen age2=(age^2)/100
label var age "Age (mean-centered)"
label var age2 "Age-squared/100 (mean-centered)"

recode v208 (1=0) (2=1), gen(female)
label var female "Female=1"

gen educ=v213 
label var educ "Education (1 no HS; 6 postgrad)"

gen income=v246
label var income "Income (1=<$10k; 14=>150k; 15=prefer not to say)"
gen incomemis = 0
replace incomemis = 1 if income==15
label var incomemis "Missing: Income"

recode v217 (1=6) (2=5) (3=4) (4=3) (5=2) (6=1), gen(religatt)
sum religatt
replace religatt=religatt-r(mean)
replace religatt=0 if religatt==.
label var religatt "Religious Attendance (never-more than 1/week [6pt, mean-centered])"

recode cc424 (1=-3) (2=-2) (3=-1) (4 8=0) (5=1) (6=2) (7=3) (*=.), gen(pid)
recode pid (-3/-1=-1) (1/3=1) (0=0) (*=.), gen(pid3)
recode v261 (1=-2) (2=-1) (3 6=0) (4=1) (5=2) (*=.), gen(ideol)
label var pid "Party ID (-3=S. Dem; 3=S. Rep)"
label var pid3 "Party ID (-1=Dem; 1=Rep)"
label var ideol "Ideology (-2=V. Lib; 2=V. Cons)"

recode v244 (1=4) (2=3) (3=2) (4=1) (7=1), gen(interest)
sum interest
replace interest=(interest-r(mean))/r(sd)
label var interest "Political Interest (M=0, SD=1; low-high)"

* Social policy opinions
recode cc09_53 (1=1) (2=2) (3=3) (4=4) (*=.), gen(abortion)
replace abortion=(abortion-1)/3
label var abortion "Pro Choice (0-1)"

recode cc09_54 (1=1) (2=0) (*=.), gen(gaymarriage)
replace gaymarriage=(gaymarriage-1)/3
label var gaymarriage "Support Gay Marriage, 1=Yes"

egen socSTDabort=std(abortion)
egen socSTDgmarr=std(gaymarriage)
gen socNSTD=((socSTDabort+socSTDgmarr)/2)*-1
egen socSTD=std(socNSTD)
label var socSTD "Social Conservatism (M=0, SD=1; liberal-conservative)"


* Party Agreement
gen p7agreement=pid*scanpty 
label var p7agreement "Party Agreement"
gen p3agreement=pid3*scanpty 
label var p3agreement "Party Agreement"

*************************************
***ESTABLISH SAMPLE, CHECK BALANCE***
*************************************
*set a sample
reg scan_vote scan_job scan_pers age age2 female interest ideol r_black r_hispanic r_other income incomemis educ pid socSTD
keep if e(sample)

save "replication.dta", replace
*/
use "replication.dta", clear
cd "tables"


*Balance Check

set more 1
mlogit scantreat age age2 female interest ideol r_black r_hispanic r_other income incomemis educ pid socSTD
foreach i in age age2 female interest ideol r_black r_hispanic r_other income incomemis educ pid socSTD{
test [1]`i' [2]`i' [3]`i' [4]`i'
}

******************** 
***CORE ANALYSIS****
********************
set more 1
**SEEMINGLY UNRELATED REGRESSION
sureg (scan_vote scandal_* age age2) (scan_job scandal_* age age2) (scan_pers scandal_* age age2) 
outreg using table_A1.doc, se squarebrack bdec(3) replace  eq_merge  varlabels summstat(r2\N)


** EQUALITY OF TREATMENTS WITHIN OUTCOMES
file open myfile using "table_A2.csv", write replace 
file write myfile "Panel A: Compare Within Outcomes,,,," _n
local outcomes="Vote Intent; Job Evaluation; Personal Evaluation"

foreach i in scan_vote scan_job scan_pers {
 gettoken outcome outcomes : outcomes, parse(;)
 gettoken dummy outcomes : outcomes, parse(;)
 file write myfile "`outcome',Infidelity,Infidelity (Abuse),Financial,Financial (Abuse)" _n
 file write myfile "Infidelity,1,,,," _n
test [`i']scandal_moral_ab=[`i']scandal_moral
 file write myfile "Infidelity (Abuse),`r(p)',-,,," _n
test [`i']scandal_fin=[`i']scandal_moral
 local pv1=r(p)
test [`i']scandal_fin=[`i']scandal_moral_ab
 file write myfile "Financial,`pv1',`r(p)',-,," _n
test [`i']scandal_fin_ab=[`i']scandal_moral
 local pv1=r(p)
test [`i']scandal_fin_ab=[`i']scandal_moral_ab
 local pv2=r(p)
test [`i']scandal_fin_ab=[`i']scandal_fin
 file write myfile "Financial (Abuse),`pv1',`pv2',`r(p)',-" _n
 file write myfile ",,,," _n
}

** EQUALITY OF TREATMENTS ACROSS OUTCOMES
local scandals="Infidelity (No Abuse); Infidelity (Abuse); Financial; Financial (Abuse)"
file write myfile "Panel B: Compare Across Outcomes,,,," _n

foreach v in scandal_moral scandal_moral_ab scandal_fin scandal_fin_ab {
 gettoken scandal scandals : scandals, parse(;)
 gettoken dummy scandals : scandals, parse(;)
 file write myfile "`scandal',Vote Intent,Job Evaluation,Personal Evaluation" _n
 // tests from SUR
 qui sureg (scan_vote scandal_* age age2) (scan_job scandal_* age age2) (scan_pers scandal_* age age2) 
 test [scan_job]`v'=[scan_vote]`v'
 local p_jv=r(p)
 test [scan_pers]`v'=[scan_vote]`v'
 local p_pv=r(p)
 test [scan_pers]`v'=[scan_job]`v'
 local p_pj=r(p)

 // bootstrapped tests
 foreach o in scan_vote scan_job scan_pers{
 qui bootstrap meandiff=(r(mu_1)-r(mu_2)), reps(1000): ttest `o' if noscandal==1 | `v'==1, by(`v') 
   matrix ses=e(se)
   matrix est=e(b)
   local n_cases=e(N)
   local `o'_sd=ses[1,1]*sqrt(`n_cases')
   local `o'_est=est[1,1]
 }
  ttesti `n_cases' `scan_job_est' `scan_job_sd' `n_cases' `scan_vote_est' `scan_vote_sd', uneq
   local p_jv_boot=r(p)
  ttesti `n_cases' `scan_pers_est' `scan_pers_sd' `n_cases' `scan_vote_est' `scan_vote_sd', uneq
   local p_pv_boot=r(p)
  ttesti `n_cases' `scan_pers_est' `scan_pers_sd' `n_cases' `scan_job_est' `scan_job_sd', uneq
   local p_pj_boot=r(p)
 file write myfile "Vote Intent,-,`p_jv_boot',`p_pv_boot'" _n
 file write myfile "Job Evaluation,`p_jv',-,`p_pj_boot'" _n
 file write myfile "Personal Evaluation,`p_pv',`p_pj',-" _n
 file write myfile ",,,," _n
}
file close myfile

********************************
******** INTERACTIONS **********
********************************
*** MODERATORS
foreach i in female interest socSTD scanpty{
foreach d of varlist scandal_*{
gen X_`d'_`i'=`i'*`d'
local label : variable label `i'

if "`i'"=="female" {
local label="Female"
}
if "`i'"=="interest" {
local label="Political Interest"
}
if "`i'"=="socSTD" {
local label="Social Conservatism"
}
if "`i'"=="scanpty" {
local label="Party of Rep."
}

local labeld : variable label `d'
label var X_`d'_`i' "`label' x `labeld'"
}
}

sureg (scan_vote scandal_* X*female X*interest X*socSTD X*scanpty age age2 female interest socSTD scanpty) (scan_job scandal_* X*female X*interest X*socSTD X*scanpty age age2 female interest socSTD scanpty) (scan_pers  scandal_* X*female X*interest X*socSTD X*scanpty age age2 female interest socSTD scanpty) 
outreg using table_A3.doc, se squarebrack bdec(3) replace  eq_merge  varlabels summstat(r2\N)
lincom [scan_job]scandal_moral
lincom [scan_job]scandal_moral+X_scandal_moral_female

